@@ -20,6 +20,7 @@ from rich_toolkit import RichToolkit
 from rich_toolkit.menu import Option
 from typing_extensions import Annotated
 
+from fastapi_cloud_cli.commands.login import login
 from fastapi_cloud_cli.utils.api import APIClient
 from fastapi_cloud_cli.utils.apps import AppConfig, get_app_config, write_app_config
 from fastapi_cloud_cli.utils.auth import is_logged_in
@@ -108,8 +109,11 @@ class DeploymentStatus(str, Enum):
     ready_for_build = "ready_for_build"
     building = "building"
     extracting = "extracting"
+    extracting_failed = "extracting_failed"
     building_image = "building_image"
+    building_image_failed = "building_image_failed"
     deploying = "deploying"
+    deploying_failed = "deploying_failed"
     success = "success"
     failed = "failed"
 
@@ -120,8 +124,11 @@ class DeploymentStatus(str, Enum):
             cls.ready_for_build: "Ready for build",
             cls.building: "Building",
             cls.extracting: "Extracting",
+            cls.extracting_failed: "Extracting failed",
             cls.building_image: "Building image",
+            cls.building_image_failed: "Build failed",
             cls.deploying: "Deploying",
+            cls.deploying_failed: "Deploying failed",
             cls.success: "Success",
             cls.failed: "Failed",
         }[status]
@@ -345,42 +352,43 @@ def _wait_for_deployment(
     with toolkit.progress(
         next(messages), inline_logs=True, lines_to_show=20
     ) as progress:
-        for line in _stream_build_logs(deployment.id):
-            time_elapsed = time.monotonic() - started_at
+        with handle_http_errors(progress=progress):
+            for line in _stream_build_logs(deployment.id):
+                time_elapsed = time.monotonic() - started_at
 
-            data = json.loads(line)
+                data = json.loads(line)
 
-            if "message" in data:
-                progress.log(Text.from_ansi(data["message"].rstrip()))
+                if "message" in data:
+                    progress.log(Text.from_ansi(data["message"].rstrip()))
 
-            if data.get("type") == "complete":
-                progress.log("")
-                progress.log(
-                    f"🐔 Ready the chicken! Your app is ready at [link={deployment.url}]{deployment.url}[/link]"
-                )
+                if data.get("type") == "complete":
+                    progress.log("")
+                    progress.log(
+                        f"🐔 Ready the chicken! Your app is ready at [link={deployment.url}]{deployment.url}[/link]"
+                    )
 
-                progress.log("")
+                    progress.log("")
 
-                progress.log(
-                    f"You can also check the app logs at [link={deployment.dashboard_url}]{deployment.dashboard_url}[/link]"
-                )
+                    progress.log(
+                        f"You can also check the app logs at [link={deployment.dashboard_url}]{deployment.dashboard_url}[/link]"
+                    )
 
-                break
+                    break
 
-            if data.get("type") == "failed":
-                progress.log("")
-                progress.log(
-                    f"😔 Oh no! Something went wrong. Check out the logs at [link={deployment.dashboard_url}]{deployment.dashboard_url}[/link]"
-                )
-                raise typer.Exit(1)
+                if data.get("type") == "failed":
+                    progress.log("")
+                    progress.log(
+                        f"😔 Oh no! Something went wrong. Check out the logs at [link={deployment.dashboard_url}]{deployment.dashboard_url}[/link]"
+                    )
+                    raise typer.Exit(1)
 
-            if time_elapsed > 30:
-                messages = cycle(LONG_WAIT_MESSAGES)  # pragma: no cover
+                if time_elapsed > 30:
+                    messages = cycle(LONG_WAIT_MESSAGES)  # pragma: no cover
 
-            if (time.monotonic() - last_message_changed_at) > 2:
-                progress.title = next(messages)  # pragma: no cover
+                if (time.monotonic() - last_message_changed_at) > 2:
+                    progress.title = next(messages)  # pragma: no cover
 
-                last_message_changed_at = time.monotonic()  # pragma: no cover
+                    last_message_changed_at = time.monotonic()  # pragma: no cover
 
 
 def _setup_environment_variables(toolkit: RichToolkit, app_id: str) -> None:
@@ -549,10 +557,33 @@ def deploy(
 
     with get_rich_toolkit() as toolkit:
         if not is_logged_in():
-            logger.debug("User not logged in, showing waitlist form")
-            _waitlist_form(toolkit)
+            logger.debug("User not logged in, prompting for login or waitlist")
 
-            raise typer.Exit(1)
+            toolkit.print_title("Welcome to FastAPI Cloud!", tag="FastAPI")
+            toolkit.print_line()
+
+            toolkit.print(
+                "You need to be logged in to deploy to FastAPI Cloud.",
+                tag="info",
+            )
+            toolkit.print_line()
+
+            choice = toolkit.ask(
+                "What would you like to do?",
+                tag="auth",
+                options=[
+                    Option({"name": "Login to my existing account", "value": "login"}),
+                    Option({"name": "Join the waiting list", "value": "waitlist"}),
+                ],
+            )
+
+            toolkit.print_line()
+
+            if choice == "login":
+                login()
+            else:
+                _waitlist_form(toolkit)
+                raise typer.Exit(1)
 
         toolkit.print_title("Starting deployment", tag="FastAPI")
         toolkit.print_line()
@@ -585,7 +616,13 @@ def deploy(
                     "App not found. Make sure you're logged in the correct account."
                 )
 
-                raise typer.Exit(1)
+        if not app:
+            toolkit.print_line()
+            toolkit.print(
+                "If you deleted this app, you can run [bold]fastapi unlink[/] to unlink the local configuration.",
+                tag="tip",
+            )
+            raise typer.Exit(1)
 
         logger.debug("Creating archive for deployment")
         archive_path = archive(path or Path.cwd())  # noqa: F841
